#define QT_FEATURE_ifr_index -1

#define QT_FEATURE_libproxy 1

#define QT_FEATURE_linux_netlink 1

#define QT_FEATURE_system_proxies 1

#define QT_FEATURE_networklistmanager -1

#define QT_FEATURE_publicsuffix_qt 1

#define QT_FEATURE_publicsuffix_system 1

